import requests


def premium_chat(*args, **kwargs):
    try:
        api_key = kwargs.get("api_key")
        query = kwargs.get('query')
        url = f"https://jarvisai.in/chatbot_premium_api?secret_key={api_key}&text={query}"
        response = requests.get(url)
        return response.json().get("message",  "Error Code=1. Server is facing some issues. Please try again later.")
    except Exception as e:
        return f"An error occurred while performing premium_chat, connect with developer. Error: {e}"


if __name__ == "__main__":
    print(premium_chat("hi"))



import os
import requests
import json


def check_local_intent(text):
    """Check if the intent of a text string is available locally.

    Args:
        text (str): The text string to check.

    Returns:
        str: The intent of the text string.
    """
    try:
        if not os.path.exists('actions.json'):
            return None
        else:
            with open('actions.json', 'r') as f:
                actions = json.load(f)
            for action in actions:
                if text in action['example']:
                    return action['intent']
    except Exception as e:
        return e


def classify_intent(secret_key, text):
    """Classify the intent of a text string using the Wit.ai API.

    Args:
        text (str): The text string to classify.

    Returns:
        str: The intent of the text string.
    """
    try:
        intent = check_local_intent(text)
        if intent is not None:
            return intent, 1.0
    except Exception as e:
        pass

    try:
        url = f'https://jarvisai.in/intent_classifier?secret_key={secret_key}&text={text}'
        response = requests.get(url)
        data = response.json()
        if data['status'] == 'success':
            return data['data'][0], data['data'][1]
    except Exception as e:
        return e, None


if __name__ == "__main__":
    intent, _ = classify_intent('527557f2-0b67-4500-8ca0-03766ade589a', "what is the time")
    print(intent, _)



import wikipedia
import re


def tell_me_about(*args, **kwargs):
    # topic = kwargs.get("query")
    entities = kwargs.get("entities")
    li = ['EVENT', 'FAC', 'GPE', 'LANGUAGE', 'LAW', 'LOC', 'MONEY', 'NORP', 'ORDINAL', 'ORG',
          'PERCENT', 'PERSON', 'PRODUCT', 'TIME', 'WORK_OF_ART']
    topic = [entity[0] for entity in entities if entity[1] in li][0]
    try:
        ny = wikipedia.page(topic)
        res = str(ny.content[:500].encode('utf-8'))
        res = re.sub('[^a-zA-Z.\d\s]', '', res)[1:]
        return res
    except Exception as e:
        print(e)
        return False
